@@ -7,6 +7,7 @@ from django.test import TestCase, tag
 from django_mock_queries.query import MockModel
 from edc_appointment.constants import TODAY, TOMORROW
 from edc_constants.constants import NO, NOT_APPLICABLE, YES
+from edc_form_validators.tests.mixins import FormValidatorTestMixin
 from edc_utils import formatted_date, get_utcnow
 from edc_visit_schedule.constants import DAY01
 
@@ -14,7 +15,7 @@ from effect_form_validators.effect_subject import (
     StudyMedicationBaselineFormValidator as Base,
 )
 
-from ..mixins import FormValidatorTestMixin, TestCaseMixin
+from ..mixins import TestCaseMixin
 
 
 class StudyMedicationMockModel(MockModel):
